@@ -92,8 +92,8 @@ module APRS4R
         return
       end
       
-      logger.warn( "gating from #{name} to #{@outDevice}, message: #{result}")
-      SocketManager.sendAPRSMessage( @outDevice, result)
+      logger.warn( "gating from #{name} to #{@outDevice}, message: #{message}")
+      SocketManager.sendAPRSMessage( @outDevice, message)
       
       return
     end
