@@ -19,27 +19,35 @@
 
 require 'aprs4r/APRSCall'
 
-class PluginConfiguration
+module APRS4R
 
-  attr_reader :name, :type, :enable
-  attr_writer :name, :type, :enable
+  class PluginConfiguration
+
+    attr_reader :name, :type, :enable
+    attr_writer :name, :type, :enable
 
 
-  def to_yaml_properties
-    return %w{ @name @type @enable}
-  end
+    def to_yaml_properties
+      return %w{ @name @type @enable}
+    end
 
 
-  def attributes
+    def attributes
 
-    pluginSelection = [ "BeaconPlugin"]
-    attributes = [ 
-                  ConfigurationAttribute.new( "name", 01, "text", "Name", 10), 
-                  ConfigurationAttribute.new( "type", 02, "select", "Typ", 10, pluginSelection),
-                  ConfigurationAttribute.new( "enable", 03, "boolean", "aktiviert", 0),
-                 ]
+      attributes = [ 
+                    ConfigurationAttribute.new( "name",   "text",    true,  10, nil,   "Name"), 
+                    ConfigurationAttribute.new( "type",   "text",    false, 10, nil,   "Typ"), 
+                    ConfigurationAttribute.new( "enable", "boolean", true,  10, false, "aktiviert"), 
+                   ]
+
+      return attributes
+    end
+
+
+    def PluginConfiguration.subtypes
+      return [ "BeaconPlugin", "ProportionalBeaconPlugin", "GatewayPlugin", "DigipeaterPlugin", "MessagePlugin", "WMRWeatherPlugin", "ISServerPlugin", "XMLDataPlugin"]
+    end
 
-    return attributes
   end
 
 end
