@@ -17,74 +17,78 @@
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 #
 
-require 'Logger'
+require 'aprs4r/APRS4RLogger'
 
 require 'aprs4r/APRSMessage'
 require 'aprs4r/Plugin'
-require 'aprs4r/WeatherConfiguration'
+require 'aprs4r/WeatherPluginConfiguration'
 
 
-class WeatherPlugin < Plugin
+module APRS4R
 
-  @@logger = Logger.get_logger( "WeatherPlugin")
+  class WeatherPlugin < Plugin
 
-  
-  def initialize( configuration)
-    @@logger.info( "initialize( configuration)")
+    @logger = APRS4RLogger.get_logger( "WeatherPlugin")
 
-    super( configuration)
+    
+    def initialize( configuration)
+      logger.info( "initialize( configuration)")
 
-    @device = configuration.device
-    @period = configuration.period
-    @offset = configuration.offset
+      super( configuration)
 
-    # template aprs message
-    @message = configuration.message
+      @device = configuration.device
+      @period = configuration.period
+      @offset = configuration.offset
 
-    return
-  end
-  
-  
-  def start 
-    @@logger.info( "start")
+      # template aprs message
+      @message = configuration.message
+
+      return
+    end
+    
+    
+    def start 
+      logger.info( "start")
+
+      if ! @enable
+        return
+      end
+
+      Thread.new{ run }
 
-    if ! @enable
       return
     end
 
-    Thread.new{ run }
 
-    return
-  end
+    def run
+      logger.info( "run")
 
+      sleep @offset
 
-  def run
-    @@logger.info( "run")
+      while true
 
-    sleep @offset
+        message = createWeatherAPRSMessage
 
-    while true
+        if message
+          logger.debug( "sending weather aprs message: #{message.to_s}")
+          SocketManager.sendAPRSMessage( @device, message)
+        end
 
-      message = createWeatherAPRSMessage
-
-      if message
-        @@logger.debug( "sending weather aprs message: #{message.to_s}")
-        SocketManager.sendAPRSMessage( @device, message)
+        sleep @period
       end
 
-      sleep @period
+      return
     end
 
-    return
+
+    def createWeatherAPRSMessage
+      logger.info( "createWeatherAPRSMessage")
+
+      logger.warn( "abstract class method")
+
+      return nil
+    end
+    
   end
 
-
-  def createWeatherAPRSMessage
-    @@logger.info( "createWeatherAPRSMessage")
-
-    @@logger.warn( "abstract class method")
-
-    return nil
-  end
-  
 end
